Module command

Module command 

Semantic commands mapped from host input before Editor::exec.

Structs

CommandResult
The result of running a command.
Point
A point in the host’s render coordinate space.

Enums

Command
An editor command.
Dir
A movement direction.
ExitDir
A direction where the caret leaves the math region.
Side
A side relative to an existing row or column.