pub enum Command {
Show 31 variants
Move(Dir),
MoveLineStart,
MoveLineEnd,
Tab,
ShiftTab,
MoveTo(Point),
Extend(Dir),
ExtendTo(Point),
SelectAll,
Collapse,
InsertAtom(Symbol),
InsertText(String),
InsertFraction(FracStyle),
InsertScript(ScriptSlot),
InsertBigOp(Symbol),
InsertSqrt,
InsertDelimiters {
open: char,
close: char,
},
InsertAccent(Mark),
InsertUnderOver(UnderOverSpec),
InsertStyled(Variant),
InsertMatrix {
env: MatrixEnv,
rows: usize,
cols: usize,
},
InsertFragment(DocFragment),
DeleteBackward,
DeleteForward,
MatrixInsertRow(Side),
MatrixDeleteRow,
MatrixInsertCol(Side),
MatrixDeleteCol,
ApplyStyle(Variant),
Confirm,
MenuSelect(usize),
}Expand description
An editor command.
Variants
Move(Dir)
Move the cursor.
MoveLineStart
Move to the line start.
MoveLineEnd
Move to the line end.
Tab
Move to the next tab stop.
ShiftTab
Move to the previous tab stop.
MoveTo(Point)
Move to a rendered point.
Extend(Dir)
Extend selection by direction.
ExtendTo(Point)
Extend selection to a rendered point.
SelectAll
Select all content.
Collapse
Collapse the selection.
InsertAtom(Symbol)
Insert a symbol atom.
InsertText(String)
Insert text.
InsertFraction(FracStyle)
Insert a fraction.
InsertScript(ScriptSlot)
Insert a script slot.
InsertBigOp(Symbol)
Insert a big operator with empty lower and upper limit slots.
InsertSqrt
Insert a radical with a degree slot and radicand.
InsertDelimiters
Insert paired delimiters.
InsertAccent(Mark)
Insert an accent.
InsertUnderOver(UnderOverSpec)
Insert an under over construct.
InsertStyled(Variant)
Insert styled content.
InsertMatrix
Insert a matrix.
InsertFragment(DocFragment)
Insert a document fragment.
DeleteBackward
Delete backward.
DeleteForward
Delete forward.
MatrixInsertRow(Side)
Insert a matrix row.
MatrixDeleteRow
Delete the current matrix row.
MatrixInsertCol(Side)
Insert a matrix column.
MatrixDeleteCol
Delete the current matrix column.
ApplyStyle(Variant)
Apply a style.
Confirm
Commit the highlighted menu row or collapse when no menu is open.
MenuSelect(usize)
Pick a visible menu row by index.