Module editor
mathtex_
editor_
core
0.1.0
Module editor
Module Items
Structs
In crate mathtex_
editor_
core
mathtex_editor_core
Module
editor
Editor owns the
Tree
, cursor, selection, host callbacks, render output, and undo snapshots.
Structs

Editor
The headless editor. Generic over the host’s callback implementation.
Undo
Entry
An opaque undo entry containing the previous document snapshot.