Slot

Enum Slot 

pub enum Slot {
Show 13 variants Numerator, Denominator, Base, Sub, Sup, Lower, Upper, Index, Radicand, Body, Over, Under, Cell { row: usize, col: usize, },
}
A named slot of a structure.

Variants



Numerator

Fraction numerator.



Denominator

Fraction denominator.



Base

Base of a script, accent, or under over construct.



Sub

Subscript.



Sup

Superscript.



Lower

Lower limit of a big operator.



Upper

Upper limit of a big operator.



Index

Degree of a radical.



Radicand

Radicand of a radical.



Body

Body of delimiters or content of a styled run.



Over

Label above an under over construct.



Under

Label below an under over construct.



Cell

Matrix cell by zero based row and column.

Fields

row: usize

Row index.

col: usize

Column index.