Host

Trait Host 

pub trait Host {
    // Required methods
    fn typeset(&self, latex: &str) -> Fragment;
    fn on_change(&self, doc: &Document);
    fn on_exit(&self, dir: ExitDir);
    fn request_close(&self);
    fn on_render(&self);

    // Provided method
    fn on_object_enter(&self, token: u32, side: Side) -> bool { ... }
}
Callbacks implemented by the host.

Required Methods

fn typeset(&self, latex: &str) -> Fragment

Typeset a LaTeX fragment to the mathtex IR.

fn on_change(&self, doc: &Document)

Handle changed content.

fn on_exit(&self, dir: ExitDir)

Handle the caret leaving the math region at a boundary.

fn request_close(&self)

Request that math mode ends.

fn on_render(&self)

Request a repaint via Editor::render.

Provided Methods

fn on_object_enter(&self, token: u32, side: Side) -> bool

Handle horizontal caret motion into a host object, true consumes the motion.

side is the direction of approach, Before when moving right and After when moving left. The default leaves the motion unconsumed, so the caret skips over the object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors