Module matcher

Module matcher 

Matcher geometry and render support for mapping model spans to mathtex IR boxes in SVG point units.

Structs

BoxMap
Geometry for each model element, resolved from the IR in points.

Functions

caret_rect
Caret rect for a cursor, using the left neighbor or next item when at sequence start.
hit_test
Reverse hit test from a point to the model cursor position.
match_boxes
Map each model element to the union of IR boxes whose source span is contained in its export range.
selection_rects
Highlight rects for a single seq selection run using the union of the run’s node boxes.