match_boxes

Function match_boxes 

pub fn match_boxes(spans: &SpanMap, fragment: &Fragment) -> BoxMap
Map each model element to the union of IR boxes whose source span is contained in its export range.