Module model

Module model 

The editable data model uses a Seq and Node tree backed by stable slotmap ids.

Structs

Cursor
A cursor is a gap in a sequence.
Node
A node, which always lives inside a sequence.
NodeId
Stable identity of a node.
Selection
A selection is a contiguous run within one sequence.
Seq
An ordered run of nodes with an optional owning node.
SeqId
Stable identity of an editable sequence.
Symbol
A leaf token plus its math class for editing heuristics.
Tree
The editable math tree.
UnderOverSpec
Spec for inserting an under/over construct.

Enums

Deco
Decoration used by under and over constructs.
FracStyle
Fraction rendering style.
Kind
Node payloads. Every editable slot is a SeqId.
Mark
Accent mark type.
MathClass
Math atom classification used by editing heuristics.
MatrixEnv
Matrix environment type.
ScriptSlot
Script slot selector.
Variant
Font or text variant.