pub struct Seq {
pub parent: Option<NodeId>,
pub items: Vec<NodeId>,
}Expand description
An ordered run of nodes with an optional owning node.
Fields
parent: Option<NodeId>The node that owns this sequence, or None for the root sequence.
items: Vec<NodeId>The ordered nodes stored in this sequence.