pub struct RenderOutput {
pub caret: Rect,
pub selection: Vec<Rect>,
pub placeholders: Vec<Rect>,
pub metrics: Metrics,
pub menu: Option<Rect>,
pub host_objects: Vec<HostObject>,
}Expand description
Everything the host paints on top of the typeset fragment.
Fields
caret: RectThe caret, a zero width rectangle.
selection: Vec<Rect>Selection highlight rectangles.
placeholders: Vec<Rect>Empty slot placeholder rectangles.
metrics: MetricsThe fragment’s size.
Where the open swap or delete menu anchors, see Editor::menu for its rows.
host_objects: Vec<HostObject>Placements of host boxes so the host can overlay their content.