Matcher geometry and render support for mapping model spans to mathtex IR boxes in SVG point units.
Structs
- BoxMap
- Geometry for each model element, resolved from the IR in points.
Functions
- caret_
rect - Caret rect for a cursor, using the left neighbor or next item when at sequence start.
- hit_
test - Reverse hit test from a point to the model cursor position.
- match_
boxes - Map each model element to the union of IR boxes whose source span is contained in its export range.
- selection_
rects - Highlight rects for a single seq selection run using the union of the run’s node boxes.